@@ -45,12 +45,13 @@ module Racc
       unless t::Racc_debug_parser then
         @yydebug = false
       end
-      @yydebug = @yydebug ? true : false
+      @yydebug = false unless defined? @yydebug
       if @yydebug then
+        @racc_debug_out = $stderr unless defined? @racc_debug_out
         @racc_debug_out ||= $stderr
       end
 
-      send Racc_Main_Parsing_Routine, t::Racc_arg, true
+      __send__ Racc_Main_Parsing_Routine, t::Racc_arg, true
     end
 
 
@@ -58,7 +59,7 @@ module Racc
       action_table, action_check, action_default, action_pointer,
       goto_table, goto_check, goto_default, goto_pointer,
       nt_base, reduce_table, token_table, shift_n, reduce_n,
-      use_result = *arg
+      use_result = arg
       if use_result.nil? then
         use_result = arg[-1] = true
       end
@@ -175,7 +176,7 @@ module Racc
           when 0
             unless user_yyerror then
               nerr += 1
-              on_error( t, val, vstack )
+              on_error t, val, vstack
             end
           when 3
             if t == t_end then
@@ -265,7 +266,7 @@ module Racc
 
 
     def on_error( t, val, vstack )
-      raise ParseError, "\nunexpected token #{val.inspect}"
+      raise ParseError, "\nparse error on value #{val.inspect}"
     end
 
 
@@ -273,7 +274,7 @@ module Racc
       action_table, action_check, action_default, action_pointer,
       goto_table, goto_check, goto_default, goto_pointer,
       nt_base, reduce_table, token_table, shift_n, reduce_n,
-      use_result = *arg
+      use_result = arg
 
       i = act * -3
       len       = reduce_table[i]
@@ -287,11 +288,11 @@ module Racc
       vstack[ -len, len ] = void_array
       state[ -len, len ]  = void_array
 
-      # tstack must be renewed AFTER method call
+      # tstack must be updated AFTER method call
       if use_result then
-        vstack.push send(method_id, tmp_v, vstack, tmp_v[0])
+        vstack.push __send__(method_id, tmp_v, vstack, tmp_v[0])
       else
-        vstack.push send(method_id, tmp_v, vstack)
+        vstack.push __send__(method_id, tmp_v, vstack)
       end
       tstack.push reduce_to
 
