@@ -11,7 +11,7 @@
 require 'sync'
 require 'delegate'
 require 'amstd/to_s'
-require 'tmail/mailp'
+require 'tmail/parsemail'
 require 'tmail/encode'
 
 
@@ -131,21 +131,22 @@ module TMail
       mod.module_eval %^
         def encoded( eol = "\r\n", charset = 'j',
                      ret = ''#{use_limit ? ', limit = 72' : ''} )
-          stra = ::TMail::HFencoder.new( ret, eol, charset,
-                   #{use_limit ? 'limit' : 'nil'}  )
-          accept stra
-          stra.write_in
+          en = ::TMail::HFencoder.new( ret, eol, charset,
+                  #{use_limit ? 'limit' : 'nil'}  )
+          accept en
+          en.write_in
           ret
         end
-        alias to_s encoded
 
         def decoded( eol = "\n", charset = 'e',
                      ret = ''#{use_limit ? ', limit = 72' : ''} )
-          stra = ::TMail::HFdecoder.new( ret, charset )
-          accept stra
-          stra.write_in
+          de = ::TMail::HFdecoder.new( ret, charset )
+          accept de
+          de.write_in
           ret
         end
+
+        alias to_s encoded
         alias inspect decoded
       ^
     end
@@ -175,12 +176,12 @@ module TMail
 
     class << self
 
-      alias objnew new
+      alias newobj new
 
       def new( fname, fbody, strict = false )
         tmp = fname.downcase
         c = (tmp[0,2] == 'x-' ? StringH : FNAME_TO_CLASS[tmp]) || UnknownH
-        c.objnew fname, fbody, strict
+        c.newobj fname, fbody, strict
       end
 
       def new_header( port, name, strict = false )
@@ -207,7 +208,7 @@ module TMail
         @attrs = nil
       end
 
-      def header_attr( name, type, flags, ali = nil )
+      def header_attr( name, type, flags, ali = nil, add = '' )
         name = _name2str( name )
         type = _type2str( type )
         r = (flags & R != 0)
@@ -236,6 +237,7 @@ module TMail
           module_eval %-
             def #{name}=( arg )
               ensure_parsed
+              #{add}
               @#{name} = arg
             end
           -
@@ -321,8 +323,7 @@ module TMail
 
     def body=( str )
       @body = str
-      @parsed = false
-      @illegal = false
+      clear_parse_status
     end
 
     def accept( strategy )
@@ -352,6 +353,11 @@ module TMail
       end
     end
 
+    def clear_parse_status
+      @parsed = false
+      @illegal = false
+    end
+
     # abstract parse
 
     # abstract do_accept
@@ -377,7 +383,7 @@ module TMail
 
     def parse
       init_real
-      TMail::HFdecoder.decode( @body )
+      @body = TMail::HFdecoder.decode( @body.gsub(/\n|\r\n|\r/, '') )
     end
 
   end
@@ -456,11 +462,10 @@ module TMail
 
     parse_on_rw
 
-    header_attr :date, Time, R | W | NODUP
-
-    def date=( arg )
-      @date = arg.localtime
-    end
+    header_attr :date, Time, R | W | NODUP, nil, <<S
+      arg = Time.at( arg.to_i )
+      arg.localtime
+S
 
     redefine_eql
     empty_able
