@@ -1,5 +1,5 @@
 #
-# setup.rb version 1.0.6
+# setup.rb version 1.0.7
 #
 #   Copyright (c) 2000 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
 #
@@ -294,8 +294,8 @@ class Installer
 
 
   def check_packdesig
-    @with = @config['with'].split(',')
-    @without = @config['without'].split(',')
+    @with = extract_dirs( @config['with'] )
+    @without = extract_dirs( @config['without'] )
 
     packs = packages
     (@with + @without).each do |i|
@@ -305,6 +305,25 @@ class Installer
     end
   end
 
+  def extract_dirs( s )
+    ret = []
+    s.split(',').each do |i|
+      if /[\*\?]/ === i then
+        tmp = Dir.glob(i)
+        tmp.delete_if {|d| not File.directory? d }
+        if tmp.empty? then
+          tmp.push i   # causes error
+        else
+          ret.concat tmp
+        end
+      else
+        ret.push i
+      end
+    end
+
+    ret
+  end
+
   def foreach_record( fn = 'PATHCONV' )
     File.foreach( fn ) do |line|
       line.strip!
